package com.ruoyi.test.seriver;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ruoyi.test.domain.DO.ExamDO;
import com.ruoyi.test.domain.DO.SingleChoiceDO;
import com.ruoyi.test.domain.ExamCreate;
import com.ruoyi.test.domain.Questionbank;
import com.ruoyi.test.domain.Vo.ExamCreateVo;
import com.ruoyi.test.domain.Vo.QuestionbankVo;
import com.ruoyi.test.domain.Vo.QuestionbankVo1;

import java.util.List;

public interface IExamDOService {

    IPage<QuestionbankVo> selectExamDoList(int pagenum,int pagesize);

    QuestionbankVo1 preview(Long id);

    int addSingleChoice(Questionbank questionbank);

    int addtfQuestions(Questionbank questionbank);

    int addMSingleChoice(Questionbank questionbank);

    int addGapFilling(Questionbank questionbank);

    int addfrQuestions(Questionbank questionbank);

}
